@@ -1,9 +1,7 @@
 package Alien::SWIProlog::Util;
 # ABSTRACT: Utilities for SWI-Prolog configuration
-$Alien::SWIProlog::Util::VERSION = '0.001_02'; # TRIAL
-$Alien::SWIProlog::Util::VERSION = '0.00102';
+$Alien::SWIProlog::Util::VERSION = '0.001';
 use Capture::Tiny qw(capture_stdout);
-use File::Spec;
 
 use constant SWIPL_ARGS => qw(
 	--dump-runtime-variables
@@ -23,30 +21,12 @@ sub get_plvars {
 
 sub plvars_to_props {
 	my ($pl, $plvars) = @_;
-
-	# older swipl have PLLDFLAGS but no PLLIBDIR
-	my $gen_PLLIBDIR;
-	if( ! exists $plvars->{PLLIBDIR} ) {
-		$gen_PLLIBDIR = File::Spec->catfile(
-			$plvars->{PLBASE},
-			'lib',
-			$plvars->{PLARCH}, )
-	}
-
 	return +{
 		'swipl-bin' => $pl,
 		home => $plvars->{PLBASE},
 		cflags => "-I$plvars->{PLBASE}/include",
-		libs => ( exists $plvars->{PLLIBDIR}
-			? join(' ', "-L$plvars->{PLLIBDIR}", $plvars->{PLLIB})
-			: join(' ', "-L$gen_PLLIBDIR", $plvars->{PLLDFLAGS}, $plvars->{PLLIB}),
-			),
-		rpath => [
-			( exists $plvars->{PLLIBDIR}
-			?  $plvars->{PLLIBDIR}
-			:  $gen_PLLIBDIR
-			)
-		],
+		libs => "-L$plvars->{PLLIBDIR} $plvars->{PLLIB}",
+		rpath => [ $plvars->{PLLIBDIR} ],
 		_PLVARS => $plvars,
 	}
 }
@@ -70,7 +50,7 @@ Alien::SWIProlog::Util - Utilities for SWI-Prolog configuration
 
 =head1 VERSION
 
-version 0.001_02
+version 0.001
 
 =head1 AUTHOR
 
